<?php
/*
 * Theme Settings
 *
 * @package Origin
 * @subpackage Template
 */

add_action( 'admin_menu', 'origin_theme_admin_setup' );

function origin_theme_admin_setup() {
    
	global $theme_settings_page;
	
	/* Get the theme settings page name */
	$theme_settings_page = 'appearance_page_theme-settings';

	/* Get the theme prefix. */
	$prefix = hybrid_get_prefix();

	/* Create a settings meta box only on the theme settings page. */
	add_action( 'load-appearance_page_theme-settings', 'origin_theme_settings_meta_boxes' );

	/* Add a filter to validate/sanitize your settings. */
	add_filter( "sanitize_option_{$prefix}_theme_settings", 'origin_theme_validate_settings' );
	
	/* Enqueue scripts */
	add_action( 'admin_enqueue_scripts', 'origin_admin_scripts' );
}

/* Adds custom meta boxes to the theme settings page. */
function origin_theme_settings_meta_boxes() {

	/* Add a custom meta box. */
	add_meta_box(
		'origin-theme-meta-box',			// Name/ID
		__( 'General settings', hybrid_get_parent_textdomain() ),	// Label
		'origin_theme_meta_box',			// Callback function
		'appearance_page_theme-settings',		// Page to load on, leave as is
		'normal',					// Which meta box holder?
		'high'					// High/low within the meta box holder
	);

	/* Add additional add_meta_box() calls here. */
}

/* Function for displaying the meta box. */
function origin_theme_meta_box() { ?>

	<table class="form-table">
	
		<!-- Font family -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'origin_font_family' ); ?>"><?php _e( 'Font family:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
			    <select id="<?php echo hybrid_settings_field_id( 'origin_font_family' ); ?>" name="<?php echo hybrid_settings_field_name( 'origin_font_family' ); ?>">
				<option value="Bitter" <?php echo hybrid_get_setting( 'origin_font_family', 'Bitter' ) == 'Bitter' ? 'selected="selected"' : '' ?>> <?php echo __( 'Bitter', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Georgia" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Georgia' ? 'selected="selected"' : '' ?>> <?php echo __( 'Georgia', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Droid Serif" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Droid Serif' ? 'selected="selected"' : '' ?>> <?php echo __( 'Droid Serif', hybrid_get_parent_textdomain() ) ?> </option>				
				<option value="Helvetica" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Helvetica' ? 'selected="selected"' : '' ?>> <?php echo __( 'Helvetica', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Istok Web" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Istok Web' ? 'selected="selected"' : '' ?>> <?php echo __( 'Istok Web', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Arial" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Arial' ? 'selected="selected"' : '' ?>> <?php echo __( 'Arial', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Verdana" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Verdana' ? 'selected="selected"' : '' ?>> <?php echo __( 'Verdana', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Lucida Sans Unicode" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Lucida Sans Unicode' ? 'selected="selected"' : '' ?>> <?php echo __( 'Lucida Sans Unicode', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="Droid Sans" <?php echo hybrid_get_setting( 'origin_font_family' ) == 'Droid Sans' ? 'selected="selected"' : '' ?>> <?php echo __( 'Droid Sans', hybrid_get_parent_textdomain() ) ?> </option>
			    </select>
			</td>
		</tr>
		
		<!-- Font size -->
		<tr>
			<th>
			    <label for="<?php echo hybrid_settings_field_id( 'origin_font_size' ); ?>"><?php _e( 'Font size:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
			    <select id="<?php echo hybrid_settings_field_id( 'origin_font_size' ); ?>" name="<?php echo hybrid_settings_field_name( 'origin_font_size' ); ?>">
				<option value="16" <?php echo hybrid_get_setting( 'origin_font_size', '16' ) == '16' ? 'selected="selected"' : '' ?>> <?php echo __( '16', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="15" <?php echo hybrid_get_setting( 'origin_font_size' ) == '15' ? 'selected="selected"' : '' ?>> <?php echo __( '15', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="14" <?php echo hybrid_get_setting( 'origin_font_size' ) == '14' ? 'selected="selected"' : '' ?>> <?php echo __( '14', hybrid_get_parent_textdomain() ) ?> </option>				
				<option value="13" <?php echo hybrid_get_setting( 'origin_font_size' ) == '13' ? 'selected="selected"' : '' ?>> <?php echo __( '13', hybrid_get_parent_textdomain() ) ?> </option>
				<option value="12" <?php echo hybrid_get_setting( 'origin_font_size' ) == '12' ? 'selected="selected"' : '' ?>> <?php echo __( '12', hybrid_get_parent_textdomain() ) ?> </option>
			    </select>
			    <span class="description"><?php _e( 'The base font size in pixels.', hybrid_get_parent_textdomain() ); ?></span>
			</td>
		</tr>		
	    
		<!-- Link color -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'origin_link_color' ); ?>"><?php _e( 'Link color:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
				<?php if ( hybrid_get_setting( 'origin_link_color' ) ) { ?>
					<input type="text" id="<?php echo hybrid_settings_field_id( 'origin_link_color' ); ?>" name="<?php echo hybrid_settings_field_name( 'origin_link_color' ); ?>" size="8" value="<?php echo esc_attr( hybrid_get_setting( 'origin_link_color' ) ); ?>" data-hex="true" />
				<?php } else { ?>
					<input type="text" id="<?php echo hybrid_settings_field_id( 'origin_link_color' ); ?>" name="<?php echo hybrid_settings_field_name( 'origin_link_color' ); ?>" size="8" value="#dd5424" data-hex="true" />
				<?php } ?>	
				<div id="colorpicker_link_color"></div>
				<span class="description"><?php _e( 'Set the theme link color.', hybrid_get_parent_textdomain() ); ?></span>
			</td>
		</tr>	    

		<!-- Custom CSS -->
		<tr>
			<th>
				<label for="<?php echo hybrid_settings_field_id( 'origin_custom_css' ); ?>"><?php _e( 'Custom CSS:', hybrid_get_parent_textdomain() ); ?></label>
			</th>
			<td>
				<textarea id="<?php echo hybrid_settings_field_id( 'origin_custom_css' ); ?>" name="<?php echo hybrid_settings_field_name( 'origin_custom_css' ); ?>" cols="60" rows="8" style="width: 98%;"><?php echo wp_htmledit_pre( stripslashes( hybrid_get_setting( 'origin_custom_css' ) ) ); ?></textarea>
				<span class="description"><?php _e( 'Add your custom CSS here. It would overwrite any default or custom theme settings.', hybrid_get_parent_textdomain() ); ?></span>
			</td>
		</tr>

		<!-- End custom form elements. -->
	</table><!-- .form-table --><?php
	
}

/* Validate theme settings. */
function origin_theme_validate_settings( $input ) {
    
    $input['origin_link_color'] = wp_filter_nohtml_kses( $input['origin_link_color'] );   
    $input['origin_font_size'] = wp_filter_nohtml_kses( $input['origin_font_size'] ); 
    $input['origin_font_family'] = wp_filter_nohtml_kses( $input['origin_font_family'] );     
    $input['origin_custom_css'] = wp_filter_nohtml_kses( $input['origin_custom_css'] );

    /* Return the array of theme settings. */
    return $input;
}

/* Enqueue scripts (and related stylesheets) */
function origin_admin_scripts( $hook_suffix ) {
    
    global $theme_settings_page;
	
    if ( $theme_settings_page == $hook_suffix ) {
	    
	    /* Enqueue Scripts */
	    wp_register_script( 'functions-admin', get_template_directory_uri() . '/admin/functions-admin.js', array( 'jquery', 'farbtastic' ), '1.0', false );
	    wp_enqueue_script( 'functions-admin' );
	    
	    /* Enqueue Styles */
	    wp_enqueue_style( 'functions-admin', get_template_directory_uri() . '/admin/functions-admin.css', false, 1.0, 'screen' );
	    wp_enqueue_style( 'farbtastic' );
    }
}

?>