<?php
/**
 * Header Template
 *
 * The header template is generally used on every page of your site. Nearly all other templates call it 
 * somewhere near the top of the file. It is used mostly as an opening wrapper, which is closed with the 
 * footer.php file. It also executes key functions needed by the theme, child themes, and plugins. 
 *
 * @package Origin
 * @subpackage Template
 */
?>

<!doctype html>
<html <?php language_attributes(); ?>>
<head>
<meta http-equiv="Content-Type" content="<?php bloginfo( 'html_type' ); ?>; charset=<?php bloginfo( 'charset' ); ?>" />
<meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    
<!-- Mobile viewport optimized -->
<meta name="viewport" content="width=device-width,initial-scale=1">

<!-- Title -->
<title><?php hybrid_document_title(); ?></title>

<?php if ( hybrid_get_setting( 'origin_font_family' ) ) {
	echo "<!-- Google Font -->\n";
	switch ( hybrid_get_setting( 'origin_font_family' ) ) {
		case 'Bitter':
			echo "<link href='http://fonts.googleapis.com/css?family=Bitter' rel='stylesheet' type='text/css'>\n";
			break;
		case 'Droid Serif':
			echo "<link href='http://fonts.googleapis.com/css?family=Droid+Serif' rel='stylesheet' type='text/css'>\n";
			break;
		case 'Istok Web':
			echo "<link href='http://fonts.googleapis.com/css?family=Istok+Web' rel='stylesheet' type='text/css'>\n";
			break;
		case 'Droid Sans':
			echo "<link href='http://fonts.googleapis.com/css?family=Droid+Sans' rel='stylesheet' type='text/css'>\n";
			break;
		default:
			echo "<link href='http://fonts.googleapis.com/css?family=Bitter' rel='stylesheet' type='text/css'>\n";
	}
} else {
	echo "<!-- Google Font -->\n<link href='http://fonts.googleapis.com/css?family=Bitter' rel='stylesheet' type='text/css'>\n";
}?>

<!-- Stylesheet -->	
<link rel="stylesheet" href="<?php echo get_stylesheet_uri(); ?>" type="text/css" />

<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />

<!-- WP Head -->
<?php wp_head(); ?>

<!-- Style settings -->
<style type="text/css" media="all">
<?php if ( hybrid_get_setting( 'origin_font_size' ) ) { ?>

	html { font-size: <?php echo hybrid_get_setting( 'origin_font_size' ); ?>px; }
<?php } ?>
<?php if ( hybrid_get_setting( 'origin_font_family' ) ) { ?>
	body { font-family: '<?php echo hybrid_get_setting( 'origin_font_family' ); ?>', serif; }
<?php } ?>
<?php if ( hybrid_get_setting( 'origin_link_color' ) ) { ?>
	a, a:visited, #footer a:hover, .entry-title a:hover { color: <?php echo hybrid_get_setting( 'origin_link_color' ); ?>; }
	#respond #submit, .button, a.button, .awp-button, #subscribe #subbutton, .wpcf7-submit, #loginform .button-primary { background-color: <?php echo hybrid_get_setting( 'origin_link_color' ); ?>; }
	a:hover, a:focus { color: #000; }
<?php } ?>	
<?php if ( hybrid_get_setting( 'origin_custom_css' ) ) {
	echo hybrid_get_setting( 'origin_custom_css' ); ?>
<?php } ?>
</style>

</head>

<body class="<?php hybrid_body_class(); ?>">

	<?php do_atomic( 'open_body' ); // origin_open_body ?>

	<div id="container">
		
		<div class="wrap">

		<?php do_atomic( 'before_header' ); // origin_before_header ?>

		<div id="header">

			<?php do_atomic( 'open_header' ); // origin_open_header ?>

				<div id="branding">
					
						<?php hybrid_site_title(); ?>
					
				</div><!-- #branding -->
				
				<?php get_template_part( 'menu', 'primary' ); // Loads the menu-primary.php template. ?>
				
				<?php hybrid_site_description(); ?>

				<?php do_atomic( 'header' ); // origin_header ?>

			<?php do_atomic( 'close_header' ); // origin_close_header ?>

		</div><!-- #header -->

		<?php do_atomic( 'after_header' ); // origin_after_header ?>

		<?php //get_template_part( 'menu', 'secondary' ); // Loads the menu-secondary.php template. ?>

		<?php do_atomic( 'before_main' ); // origin_before_main ?>

		<div id="main">

			<?php do_atomic( 'open_main' ); // origin_open_main ?>